Function ring13::test::from_file

source ·
pub fn from_file<F>(test_data_relative_file_path: &str, f: F)where
    F: FnMut(&str, &mut TestCase) -> Result<(), Unspecified>,
Reads test cases out of the file with the path given by test_data_relative_file_path, calling f on each vector until f fails or until all the test vectors have been read. f can indicate failure either by returning Err() or by panicking.